@@ -1,12 +1,11 @@
 # -*- coding: utf-8 -*-
 
 import configargparse
-from github import Github
 
 from decay.analyzers import analyze_path
 from decay.comms import send_results
-from decay.context import DocCheckerContext
-from decay.feedback import error
+from decay.context import DocCheckerContext, ACTIONS
+from decay.marker import mark_files
 
 
 def get_parser():
@@ -18,10 +17,18 @@ def get_parser():
         config_file_parser_class=configargparse.YAMLConfigFileParser
     )
 
+    parser.add_argument('actions', metavar='ACTION', type=str, nargs='+', choices=ACTIONS)
+
     parser.add_argument('-c', '--config', required=False, is_config_file=True,
                         help='Path to YAML configuration file')
+
     parser.add_argument('-o', '--github_owner', dest="github_owner", required=True,
                         help="The organization name is the owner")
+    parser.add_argument('-i', '--ignore_path', action='append', dest="ignore_paths", required=False,
+                        help="Use this for each path that should be skipped by the decay detector.")
+    parser.add_argument('-n', '--ignore_file', action='append', dest="ignore_files", required=False,
+                        help="Use this for each file that should be skipped by the decay detector.  This should be "
+                             "the path to the file in the repo.")
     parser.add_argument('-g', '--github_repo', dest="github_repo", required=True,
                         help="The repository name (excluding the path)")
     parser.add_argument('-f', '--github_repo_folder', dest="github_repo_folder", required=True,
@@ -54,13 +61,8 @@ def main(argv=None):
     parser = get_parser()
     args = parser.parse_args(args=argv)
     ctx = DocCheckerContext(args, parser)
-    gh = Github(login_or_token=ctx.github_token, per_page=10)
-    target_repo = gh.get_repo(f"{ctx.github_repo_owner}/{ctx.github_repo}")
-    if not target_repo:
-        error(f"Unable to find the {ctx.github_repo_owner}/{ctx.github_repo} repo.")
-        exit(1)
-
-    analyzed_results = analyze_path(target_repo, ctx.github_repo_path, ctx)
+    analyzed_results = analyze_path(ctx.github_repo_path, ctx)
+    mark_files(analyzed_results, ctx)
     send_results(analyzed_results, ctx)
 
 
